aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrCoordTransform.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gpu/GrCoordTransform.cpp')
-rw-r--r--src/gpu/GrCoordTransform.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gpu/GrCoordTransform.cpp b/src/gpu/GrCoordTransform.cpp
index b22f3258fc..9c6815ec84 100644
--- a/src/gpu/GrCoordTransform.cpp
+++ b/src/gpu/GrCoordTransform.cpp
@@ -15,13 +15,13 @@
static GrSLPrecision compute_precision(const GrShaderCaps* caps,
int width, int height,
GrSamplerParams::FilterMode filter) {
// Always start at kDefault. Then if precisions differ we see if the precision needs to be
// increased. Our rule is that we want at least 4 subpixel values in the representation for
// coords between 0 to 1 when bi- or tri-lerping and 1 value when nearest filtering. Note that
// this still might not be enough when drawing with repeat or mirror-repeat modes but that case
// can be arbitrarily bad.
int subPixelThresh = filter > GrSamplerParams::kNone_FilterMode ? 4 : 1;
- GrSLPrecision precision = kDefault_GrSLPrecision;
+ GrSLPrecision precision = kMedium_GrSLPrecision;
if (caps) {
if (caps->floatPrecisionVaries()) {
int maxD = SkTMax(width, height);
@@ -15,13 +15,13 @@
int width, int height,
GrSamplerParams::FilterMode filter) {
- // Always start at kDefault. Then if precisions differ we see if the precision needs to be
+ // Always start at kMedium. Then if precisions differ we see if the precision needs to be
// increased. Our rule is that we want at least 4 subpixel values in the representation for
// coords between 0 to 1 when bi- or tri-lerping and 1 value when nearest filtering. Note that